;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#x06367dde9c1e95c0038ae42d2febfcb8 . "./code.cg2js/cg-acache.fasl")
(#x94c56e3d3e25120e9cd110c9f8bac6f2 . "./code.cg2js/cg-base.fasl")
(#x92f9b1dff4c9b100cff663d034ec97f3 . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#x5385ed8a7249b22cada1f786a4a1a4c8 . "./code.cg2js/cg-bitmap-pane.fasl")
(#xdccde386edac157e9689cf4aecf97d6b . "./code.cg2js/cg-bitmap-stream.fasl")
(#xf7b14e9bb79ad3c0a6206ceae1047499 . "./code.cg2js/cg-button.fasl")
(#x910dc916cbd5eabf14c91e531e1b97fd . "./code.cg2js/cg-calendar.fasl")
(#xf15c9094c256883d5d38c6517b62e142 . "./code.cg2js/cg-caret.fasl")
(#x8448fefb605cf19411021966abbc8572 . "./code.cg2js/cg-chart-or-plot.fasl")
(#x090624d9d2cd8d2deff6eabc704e420f . "./code.cg2js/cg-chart-widget.fasl")
(#xc83d54fc159126fb4e2c968f9ed6066e . "./code.cg2js/cg-check-box.fasl")
(#x122b6f90e91a947823b66ceb8399c921 . "./code.cg2js/cg-choice-list.fasl")
(#xf08ab859e4ad4576e36a7f5fbf66346c . "./code.cg2js/cg-choose-printer.fasl")
(#x8e3d7d76deb7a6f6f9c7e569422fc768 . "./code.cg2js/cg-class-grid.fasl")
(#xf63c2939147a746857654b15ea779727 . "./code.cg2js/cg-class-slot-grid.fasl")
(#x3910622e97473a05526050bb93c5d8dc . "./code.cg2js/cg-class-support.fasl")
(#xa6ece3ff21b24f0dac87bb0b1bce5b1c . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#x4ebca572731e1ea797791d3e78ded0fe . "./code.cg2js/cg-clipboard-stack.fasl")
(#x3f3a5469590f0fad99ed07558b210649 . "./code.cg2js/cg-clipboard.fasl")
(#x738cd54ef81929b0ecbb2cd5efdd4811 . "./code.cg2js/cg-color-dialog.fasl")
(#x6962db563d5af0ea52ab2d3b994c578e . "./code.cg2js/cg-combo-box.fasl")
(#x21cd8297eea369882e1acf74122129d1 . "./code.cg2js/cg-common-control.fasl")
(#xb801423c5fc46339fef5242fe20f61b9 . "./code.cg2js/cg-comtab.fasl")
(#x0d75de33160f31800d9391d0968fc8e5 . "./code.cg2js/cg-cursor-pixmap.fasl")
(#x492e3d24c9d475d4cc6b131226daae16 . "./code.cg2js/cg-curve.fasl")
(#x810c5f4afba3b8f1fe099e2fd02e6b2a . "./code.cg2js/cg-dde-utils.fasl")
(#x769d25933641e80fabe9859f1c34a603 . "./code.cg2js/cg-dev.fasl")
(#x26a79db6b631a788c33291b94ba9f72a . "./code.cg2js/cg-dialog-item.fasl")
(#x981b4380aaf69bc2f18d6157e6345784 . "./code.cg2js/cg-directory-dialog-os.fasl")
(#xb17cd33326d65d415f31cce1996339b9 . "./code.cg2js/cg-directory-dialog.fasl")
(#x8163ffe581ad8016a533ada36625aa1d . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#x310ccad71a4dbafd4f9c53443ce75c49 . "./code.cg2js/cg-drag-and-drop.fasl")
(#xa99c96cd6db7de920f7ebe6480f1bb85 . "./code.cg2js/cg-drawable-clipboard.fasl")
(#x4c36d71fd98e716c8d7ac7b33d472bd6 . "./code.cg2js/cg-drawable.fasl")
(#x7c0d140e7af739743eb4129d5e43deb7 . "./code.cg2js/cg-dropping-outline.fasl")
(#xe9d6174805b08930525517c759bebbf6 . "./code.cg2js/cg-edit-in-place.fasl")
(#x7528922d72b1e5c9c40d85767b123b72 . "./code.cg2js/cg-editable-text.fasl")
(#x700e51855b7a92fa4aaeb110c41d0049 . "./code.cg2js/cg-file-dialog.fasl")
(#x00b058a35343800059ce6f05000e6775 . "./code.cg2js/cg-fill-texture.fasl")
(#xf012af4d8117aae206143a5aeca9b147 . "./code.cg2js/cg-find-string-dialog.fasl")
(#x1bee439f230b8c89c9bc3f70033d610f . "./code.cg2js/cg-font-dialog.fasl")
(#xe8a15804fc70f6a8f90cb24020d86c39 . "./code.cg2js/cg-gesture-emulation.fasl")
(#xa77a8fee51901e9ec736ec3f81498ef1 . "./code.cg2js/cg-get-pixmap.fasl")
(#x9173c0daf0608c77ae29d5ef6c3be280 . "./code.cg2js/cg-get-position.fasl")
(#xbbd74b1d7512a2eda49a508bfc75897e . "./code.cg2js/cg-graphics-context.fasl")
(#x461a9e420dea944419f4133238e5196f . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#x9fb78641382194da6c7a383489a25e7c . "./code.cg2js/cg-grid-widget.fasl")
(#x492091c383a18d5c2414dea56f1019e3 . "./code.cg2js/cg-group-box.fasl")
(#x47033ef19d691a2fb372a9b3a6b2567f . "./code.cg2js/cg-header-control.fasl")
(#xaf3bce062d4c53c2ed0b50c58af1e310 . "./code.cg2js/cg-hotspot.fasl")
(#xeb26f346d2c9e1d9968795f3ef7cda4a . "./code.cg2js/cg-html-dialog.fasl")
(#xa89dbfcece24d243a8f68f6dd18c22a3 . "./code.cg2js/cg-html-widget.fasl")
(#x89f022a55cb7f059b7e09826a3e7269d . "./code.cg2js/cg-icon-pixmap.fasl")
(#x503c472c71b47c14552eb87df51618ec . "./code.cg2js/cg-icon.fasl")
(#x98d5f5f791d48228b92c8254989835d0 . "./code.cg2js/cg-ie.fasl")
(#x7569e9da1ac95458c855f2d98036ab02 . "./code.cg2js/cg-intersect-posbox.fasl")
(#x9dec936a04e6bd0b8e5307bdd7eca261 . "./code.cg2js/cg-intersect.fasl")
(#xbeb7a920f1f679bd39675440f97738eb . "./code.cg2js/cg-item-list.fasl")
(#xbd4eb5465a2b1def0b55a3cdbb8d0bb7 . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#x71e22480b7f753dd17723e831b93bc20 . "./code.cg2js/cg-lamp.fasl")
(#x608eee8a1ad4955ecaf4096a17449b1a . "./code.cg2js/cg-layout.fasl")
(#x22e6ebdb09f5f47e53d94bb81fd60cd4 . "./code.cg2js/cg-lettered-menu.fasl")
(#x59ae0b99936bff79a665bb5bb6008483 . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#x5e5591a6fdacd1be5b58f2c889c26a94 . "./code.cg2js/cg-lisp-text.fasl")
(#x13cd9389911f37409ada404c63d87dd8 . "./code.cg2js/cg-lisp-widget.fasl")
(#x8d09c800c1f14b17f2b0a6c0589f36ba . "./code.cg2js/cg-list-view.fasl")
(#xbbb145f91389d0e65dc64ab1c38b9863 . "./code.cg2js/cg-mci.fasl")
(#x44f43e8230fc3044d392a4435493031f . "./code.cg2js/cg-menu-tooltip.fasl")
(#x8c39a291cc4653219185cdc288754a44 . "./code.cg2js/cg-menu.fasl")
(#x439d694be0ffe086f4f5b7b15c372240 . "./code.cg2js/cg-message-dialog.fasl")
(#x2a036e501c1d4bc0ad8b14075adc0716 . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#x0351667d6c16587c2b3ba8e2914633c6 . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#x320077d69cf8c3ebe1c0b85ff2855936 . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#x277543b8317925296caceb1c0280f50a . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#xe4472211fa01cadf79b5082ca4a5a9cf . "./code.cg2js/cg-multi-picture-button.fasl")
(#xc0856523a62a7244fdf1255cfced5e00 . "./code.cg2js/cg-nodes.fasl")
(#x18c7bcd001e2edcf4c0d73c22f35fd76 . "./code.cg2js/cg-object-editor-layout.fasl")
(#x4ef64e092f95b99d64d18206ae5e1d65 . "./code.cg2js/cg-object-editor.fasl")
(#x6b6a9ee215bd7a90646f06e4edf38118 . "./code.cg2js/cg-ocx.fasl")
(#xe22822d75ba2a96d3a073f2c745a7559 . "./code.cg2js/cg-os-widget.fasl")
(#xa682cee7a5dcd0470ba5c45d33e50f87 . "./code.cg2js/cg-os-window.fasl")
(#xd0aee0287898cd9dea40436d285ff7d5 . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#x5e9ca32081d38141171ef2b5ea9b06e9 . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#x5cf0ceec7b54c6ee6f2bab38031d95de . "./code.cg2js/cg-outline.fasl")
(#x3b387d8e4e1f01ab404b319afe71544f . "./code.cg2js/cg-palette.fasl")
(#xa98b3eff398c5100d9a3a41ceede9350 . "./code.cg2js/cg-paren-matching.fasl")
(#xba4e20c8a6416f62624f29505cf5db71 . "./code.cg2js/cg-picture-widget-palette.fasl")
(#x02a5fdc49efce1733aa916bbf20d260f . "./code.cg2js/cg-picture-widget.fasl")
(#x0faf32a492eee9a7ccdd2a3a4387910e . "./code.cg2js/cg-pixmap-file-io.fasl")
(#x3803efeb0734b8599ea020d6ecc60a35 . "./code.cg2js/cg-pixmap-printing.fasl")
(#x8d57d8e8d782d2d36fef0e79ee708a10 . "./code.cg2js/cg-pixmap-rotate.fasl")
(#xa9c75393abeecac57da783fcbc7563aa . "./code.cg2js/cg-pixmap-widget.fasl")
(#x148dba35d1c17a6a6d1310d885efd9dc . "./code.cg2js/cg-pixmap.fasl")
(#x9d929da2cdbb1d4ad26ae7f0e2a6b555 . "./code.cg2js/cg-player.fasl")
(#x8a8b952aaa088c75523b003b2fd99404 . "./code.cg2js/cg-plot-widget.fasl")
(#xf954d765e57e854d4c02a41242d2577a . "./code.cg2js/cg-printing.fasl")
(#x8c50c994da607c3d5ec147e3a90ebcd9 . "./code.cg2js/cg-progress-indicator.fasl")
(#x9141e6fb6d0dbd8d33cb6b95b724db64 . "./code.cg2js/cg-project-window.fasl")
(#xcdcb04d34434167343a740172f3b777b . "./code.cg2js/cg-property.fasl")
(#x2c5d4b545612c91818bc9827ca98b331 . "./code.cg2js/cg-radio-button.fasl")
(#x994a62e221d3e0405c134949f69395b7 . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#xa0d050b4e4bc7dfa37bd4e71ede4cb88 . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#x1770f5b2fa368f7f5e564948af953fe6 . "./code.cg2js/cg-rich-edit-pane.fasl")
(#x6260d00f353a9352f66ba28fa161b074 . "./code.cg2js/cg-rich-edit.fasl")
(#xa4f2fcb3252fff298ee8bc886981f0a7 . "./code.cg2js/cg-sample-file-menu.fasl")
(#x479038e0d38092762835d2a4a5f3701a . "./code.cg2js/cg-scaling-stream.fasl")
(#x695dfd32fcdb689d5603933f4843f2f2 . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#xc5e62aa13c6f07a4da65400d6f4ba697 . "./code.cg2js/cg-scroll-bar.fasl")
(#x1750f6ef5b7a44f5387f563180fe3822 . "./code.cg2js/cg-scrolling-static-text.fasl")
(#x6f865e2ebfb13f0cc817cb39e5df26af . "./code.cg2js/cg-selected-object.fasl")
(#x17687e40e67cb14352a8d134e9433244 . "./code.cg2js/cg-shortcut-menu.fasl")
(#xa1d5cd358301eeb14039f38264fe8973 . "./code.cg2js/cg-split-bar.fasl")
(#x2d9a30b47fdcf8d084b58b128d19139d . "./code.cg2js/cg-static-text.fasl")
(#xd0ab69405b338fe02c0e1836b3894413 . "./code.cg2js/cg-status-bar.fasl")
(#x015ca336fb8846b6350baf25d8491a5d . "./code.cg2js/cg-string-dialog.fasl")
(#x6e0709836e1f35b1ff3b3266f67137f2 . "./code.cg2js/cg-tab-control.fasl")
(#xc8c77ecfd3f0a3f4e18fbb715893405e . "./code.cg2js/cg-template-string.fasl")
(#x6c2c1078285d00f815a54414769ff2c1 . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#x9396be6a7b6afe63b4ac77fbe2939694 . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#x242a40b77b07dfbb61846b08154c2eb5 . "./code.cg2js/cg-text-edit-pane.fasl")
(#x1e5bc93af099981fbef94711f0880e69 . "./code.cg2js/cg-text-or-combo.fasl")
(#x550a40e46f9bdd639d9a7279c9b01b81 . "./code.cg2js/cg-text-widget.fasl")
(#x1f1b02d4ae173b3609ef7fcf0a1cd5de . "./code.cg2js/cg-timer.fasl")
(#x27d1ec36930a2dce31a0d9e0e4504e87 . "./code.cg2js/cg-toggling-widget.fasl")
(#xc2c7cf40b41946caaf5d92ed372a91b3 . "./code.cg2js/cg-toolbar.fasl")
(#xce28b31be0be8262cc96eb718a0cb077 . "./code.cg2js/cg-tooltip.fasl")
(#x6fbd9d1c4ef8eb3cfeb4635a1f18d91b . "./code.cg2js/cg-touch.fasl")
(#x3027131031c4bd13d1ce8bb73ae84556 . "./code.cg2js/cg-trackbar.fasl")
(#x898ad411783a4b3508fdccb11673b826 . "./code.cg2js/cg-tray.fasl")
(#x66e559dd8a83f4339464e87816928cf9 . "./code.cg2js/cg-up-down-control.fasl")
(#x6b47447cbc4a907f9d0546e441f94f97 . "./code.cg2js/cg-utility-dialog.fasl")
(#xc1d579541e93602df9b4fd6f3539cf87 . "./code.cg2js/cg-web-browser-dde.fasl")
(#x1381bdf97ca333bc29fd6a153497927b . "./code.cg2js/cg-web-browser.fasl")
(#xea3689769aa14fae922344320dccd8b6 . "./code.cg2js/cg-wrap-string.fasl")
(#x0b1ea72def4cab6c60bd88fe046f7401 . "./code.cg2js/cg-yes-no-list.fasl")
(#x23dc12c0a04719579f88f531149dc2e4 . "./code.cg2js/cg.fasl")
(#x767617c4e007436b1beb484e65367bdf . "./code.cg2js/cg-yes-no-string.fasl")
(#xb3308f489df6599aad9945896e6b590c . "./code.idejs/ide-acache.fasl")
(#x0cb12ce80d103c82ea7615f94f758e1c . "./code.idejs/ide-apropos.fasl")
(#x2ca8e05d20519abf54c4d52b2212fa06 . "./code.idejs/ide-base.fasl")
(#xcc793fa22667b799de7320569fe260d8 . "./code.idejs/ide-class-browser.fasl")
(#x1516a6cf7ca729cb7a15af9507cb6705 . "./code.idejs/ide-class-grapher.fasl")
(#xd741dcaec9d19cb79ded83ab29324209 . "./code.idejs/ide-clipboard.fasl")
(#x9b3693bf3bff18ee1f0a16a3336c59db . "./code.idejs/ide-dev.fasl")
(#xf532aba5f5b2f66c2ea5edb667e6ef4f . "./code.idejs/ide-editor.fasl")
(#x3294020c90c99cc911676006102cdb72 . "./code.idejs/ide-find-definitions.fasl")
(#x60026d132341547df7d72304aa186c74 . "./code.idejs/ide-find-in-files.fasl")
(#x4ed269da927ad094f71595f6eb222b25 . "./code.idejs/ide-form.fasl")
(#x70611afcc50ba31ea554824f82baea74 . "./code.idejs/ide-grapher.fasl")
(#xa02a005f779543bc6e46487f7a196242 . "./code.idejs/ide-inspector.fasl")
(#xb0e8fea7f18f76f51ef9d5641c664e14 . "./code.idejs/ide-intro.fasl")
(#xc95e891ec340f99d11accbdf350ce4b6 . "./code.idejs/ide-keyshort.fasl")
(#x5f3f44cd69bbc171014260b64c61136d . "./code.idejs/ide-navigator.fasl")
(#xe9bcb4ef9a613251d65032b9d6579c54 . "./code.idejs/ide-package-list.fasl")
(#x013485d14d1695e2c8f09f1c2fd91674 . "./code.idejs/ide-patch-dialog.fasl")
(#x6edd3663d3a44848a92c810bcc58bab8 . "./code.idejs/ide-process-browser.fasl")
(#x24608b43ca010d62d9c5b37837f068ca . "./code.idejs/ide-project.fasl")
(#x5f1e745939759e083aa4b537fe55b457 . "./code.idejs/ide-trace.fasl")
(#xb6370cd83cd24ef4c311f71718bb8c1d . "./code.idejs/ide-window-list.fasl")
(#x7811966a0c925ef9180d6bbd8b0d6f1d . "./code.idejs/ide.fasl")
(#xde049c9404b4ba293f0cbc6a4817dc96 . "./cgjs.html")
(#x55fea08d92e113f5a8381c271febbc9e . "./ssl-not-found.html")
(#x4e1b21622d7d9cc4e6fc09c7875f8430 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (format t "Incorrect checksum on file: ~a" (cdr checksum))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js" "code.idejs"))
    (format s "
(let ((path (make-pathname
             :host \"sys\"
             :directory '(:relative \"~a\")
	     :type \"fasl\"
	     )))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows
  (let ((noninteractive (sys:getenv "ACL_NONINTERACTIVE")))
    (when (or (null noninteractive)
	      (string= "" noninteractive))
      (excl::internal-message-box msg "CG/JS Installation" :type :ok))))
